********************************************************************************
** harmonizing datasets: PAPFAM 2009 and JLMPS 2016
** Caitlyn Keo, Caroline Krafft, Mariam Sharpless
** Original 1/28/2018
** Updated 10/12/2018
** v13
********************************************************************************

*******************************************
*Merge PAPFAM Household and Member files
*******************************************

*merge HH and HR on household ID (cluster + hhnum)
use "Data/HH.DTA", clear
merge 1:m cluster hhnum using "Data/HR.DTA"
	rename _merge _merge_HR
	sort cluster hhnum ln
	
	tab result _merge_HR
	*merge_HR==1 are all households that were not completed

compress	
	
save "Data/HH_HR_merge.dta", replace

****************************************
**Prep PAPFAM for append 
****************************************

*Keep successful result households
keep if result==1

*Identifier for dataset
gen PAPFAM=1

*weights
* desc_weight_HH : expan_hh in JLMPS | hhweight in PAPFAM
* desc_weight_indiv : expan_indiv in JLMPS | hhweight in PAPFAM

gen desc_weight_HH=hhweight
gen desc_weight_indiv=hhweight

*Household and individual ids

gen str2 _hhnum = string(hhnum,"%02.0f")
gen str4 _cluster = string(cluster,"%04.0f")
gen str2 _ln = string(ln,"%02.0f")

gen hhid="09"+_cluster+_hhnum
gen indid=hhid+_ln

label var hhid "Unique household id"
label var indid "Unique individual id"

*Check
isid indid

*************
*Covariates
*************

*Renames for harmonization
rename XH105A age
rename ln pn
rename H103 sex
rename H105Y brthyr 

*Age in December of interview year (determines enrollment)
gen dec_age=floor((2009-brthyr)+(12-H105M)/12)

la def Ldec_age 7 "7" 8 "8" 9 "9" 10 "10" 11 "11" 12 "12" ///
13 "13" 14 "14" 15 "15" 16 "16" 17 "17" 18 "18" 19 "19" 20 "20" 21 "21" 22 "22"
la val dec_age Ldec_age

*Binary current enrollment: student
gen student=1 if H110A==1 
replace student=0 if H110A==2 | H110A==3

label variable student "currently enrolled in school"
tabu student H110A

rename cluster psu

keep hhid indid psu hhnum pn hhweight sex age dec_age gov PAPFAM  ///
brthyr desc_weight_HH desc_weight_indiv student


compress   

save "Data/PAPFAM- educ.dta", replace


****************************************
**Prep JLMPS for append
****************************************

use "Data/JLMPS 2016 xs v1.1.dta", clear


gen JLMPS2016=1

*weights
* desc_weight_HH : expan_hh in JLMPS | hhweight in PAPFAM
* desc_weight_indiv : expan_indiv in JLMPS | hhweight in PAPFAM

gen desc_weight_HH=expan_hh
gen desc_weight_indiv=expan_indiv

*Age in September of interview year
gen dec_age=floor((2016-brthyr)+(12-brthm)/12)

*Dropout as never or leaving
gen dropout=1 if q3001==2 | q3001==1
replace dropout=0 if q3001==3

*Cleaning years of school
replace yrschl=dec_age-6 if yrschl>dec_age-4 & yrschl!=.
replace yrschl=0.001 if yrschl==0

*Grouping Mother Education Levels into 3 (illiterate, read&write, basic and above)
gen motheredcat= 1 if mteducst==1
replace motheredcat=2 if mteducst==2
replace motheredcat=3 if mteducst==3 | mteducst==4 | mteducst==5 | mteducst==6

tab mteducst motheredcat, miss

label define Lpeduc_3 1 "Illiterate" 2 "Read & write" 3 "Basic+"
label values motheredcat Lpeduc_3


*Grouping Father Education Levels into 3 (illerate, read & write, basic and above)
gen fatheredcat= 1 if fteducst==1
replace fatheredcat=2 if fteducst==2
replace fatheredcat=3 if fteducst==3 | fteducst==4 | fteducst==5 | fteducst==6

tab fteducst fatheredcat, miss

label values fatheredcat Lpeduc_3

*generate number of older and younger siblings by sex
gen older_sibs=nsibs-q2417+1
gen younger_sibs=nsibs-older_sibs

gen older_sisters=nsisters-q2418+1 if sex==2
gen older_brothers=nbrothers-q2418+1 if sex==1

replace older_brothers=older_sibs-older_sisters if sex==2
replace older_sisters=older_sibs-older_brothers if sex==1

gen younger_sisters=nsisters-older_sisters
gen younger_brothers=nbrothers-older_brothers

gen check=younger_sisters+younger_brothers+older_brothers+older_sisters
tabu check nsibs if nsibs!=check

foreach var of varlist older_* younger_* {
replace `var'=0 if `var'<0
}

*Switch to presence
replace older_brothers=1 if older_brothers!=0
replace older_sisters=1 if older_sisters!=0
replace younger_brothers=1 if younger_brothers!=0
replace younger_sisters=1 if younger_sisters!=0


la var older_brothers "Have older brother"
la var older_sisters "Have older sister"
la var younger_brothers "Have younger brother"
la var younger_sisters "Have younger sisters"

*Nationality

gen group=.
replace group=1 if nationality==400
replace group=2 if nationality==405 

la def Lgroup 1 "Jordanians 2016" 2 "Syrians in Jordan 2016" 3 "Syrians 2009", modify
la val group Lgroup


*generate variable for arriving in Jordan
gen year_arrived=.

foreach num of numlist 1/9 {
replace year_arrived=q2147_`num' if year_arrived==. & q2144_`num'==1
}

*Shifting up earlies
replace year_arrived=2011 if year_arrived<2011

*Putting at 2013 if missing
replace year_arrived=2013 if year_arrived==9998 | year_arrived==.

gen year_arrived_short=year_arrived
replace year_arrived_short=2016 if year_arrived==2017

la def Lyear_arrived_short 2011 "<2012" 2012 "2012" 2013 "2013" 2014 "2014" ///
2015 "2015" 2016 "2016+" 
la val year_arrived_short Lyear_arrived_short


*Interruption
gen interrupt=1 if q2123==2 & q3001==3
replace interrupt=2 if q2123==2 & q3001==2
replace interrupt=3 if q2123==1 & q3001==3
replace interrupt=4 if q2123==1 & q3001==2

la def Linterrupt 1 "No interrupt.- still student" ///
2 "No interrupt.- dropped out" ///
3 "Interrupt.- still a student" ///
4 "Interrupt.- dropped out"  

la val interrupt Linterrupt

tabu interrupt

tabu interrupt q3001, miss
tabu interrupt q2123, miss

*PSU
rename Fpsu psu
destring psu, replace

*Keeping
keep indid hhid pn psu sex age gov JLMPS2016 brthyr  ///
desc_weight_HH desc_weight_indiv student ///
fatheredcat motheredcat yrschl group nationality dec_age dropout ///
q3001 q2121 q2122 q2123 q2125 q2126 q2128 expan* ///
q3018 q3019 q3032 q3033 q3043 q3044 q3006_a q3006_b year_arrived year_arrived_short ///
interrupt q3046 q3039 q3045 q3047 ///
q3020 q3021 q3011 q3012 q2129 gov district subdistrict locality ///
q2144* q2147* q2145* older_* younger_* nsibs ///
usemp1 uslfsr1

compress

save "Data/JLMPS refugees- educ.dta", replace

****************************************
**Append 
****************************************

use "Data/PAPFAM- educ.dta", clear

append using "Data/JLMPS refugees- educ.dta"

replace PAPFAM=0 if PAPFAM==.
replace JLMPS2016=0 if JLMPS2016==.

label define J 0 "PAPFAM 2009" 1 "JLMPS 2016" 
label values JLMPS2016 J

replace group=3 if PAPFAM==1  

compress

save "Data/Syrians pre and post crisis- educ.dta", replace


***************************
*Annualized dropouts - for multivariate model
***************************

*Use JLMPS data only 
use "Data/JLMPS refugees- educ.dta", clear

replace yrschl=0 if yrschl<1

/*Dates */

*Year start basic
gen yrstart_basic=q2121 if q2121!=9998 & q2121!=9999
replace yrstart_basic=q2122+brthyr if q2121==9998 & q2122!=98

*Year finish basic
gen yrcomplete_basic=q3043 if q3043!=9998 & q3043!=9999
replace yrcomplete_basic=q3044+brthyr if q3043==9998 & q3044!=98 & q3044!=99

*Year complete secondary (no start)
gen yrcomplete_secondary=q3032 if q3032!=9998 & q3032!=9999
replace yrcomplete_secondary=brthyr+q3033 if q3032==9998 & q3033!=98 & q3033!=99

*Year start higher education
gen yrstart_he=q3018 if q3018!=9998 & q3018!=9999
replace yrstart_he=brthyr+q3019 if q3018==9998 & q3019!=98 & q3019!=99

*Year complete higher education
gen yrcomplete_he=q3020 if q3020!=9998 & q3020!=9999
replace yrcomplete_he=brthyr+q3021 if q3020==9998 & q3021!=98 & q3021!=99

*Year complete post-grad (no start)
gen yrcomplete_post=q3011 if q3011!=9998 & q3011!=9999
replace yrcomplete_post=brthyr+q3012 if q3011==9998 & q3012!=98 & q3012!=99

*Expand for one observation per year completed and a zero for entry
expand yrschl+ 1 

*Data are grades, 0 to highest completed
bysort indid: gen grade=_n-1

*Event: dropped in that year
gen dropped = 1 if dropout==1 & grade==yrschl
replace dropped=0 if dropout==1 & grade!=yrschl
replace dropped=0 if dropout==0

label variable dropped "dropped out in this year"


******************
*Calendar year
******************

sort indid grade

*Age six for start if no other info/never went
bysort indid: gen year=brthyr+(_n-1) + 6

*Start of basic (and using that as an approx. for all subsequent)
bysort indid: replace year=yrstart_basic + (_n-1) if yrstart_basic!=.

*End of basic
replace year=yrcomplete_basic if yrcomplete_basic!=. & grade==10
replace year=yrcomplete_basic+(grade-10) if yrcomplete_basic!=.

*End of secondary 
replace year=yrcomplete_sec if yrcomplete_sec!=. & grade==12

*Start of HE
bysort indid: replace year=yrstart_he+(grade-12) if grade>=13 & yrstart_he!=.

*Finish of HE
replace year=yrcomplete_he if grade==yrschl & yrcomplete_he!=. & (q3006_a==5 | q3006_a==6)
replace year=yrcomplete_he if grade==16 & yrcomplete_he!=. & (q3006_a==7 | q3006_a==8)

*Finish of Post-grad
replace year=yrcomplete_post if grade==yrschl & yrcomplete_post!=. & (q3006_a==7 | q3006_a==8)

*Interruptions
bysort indid: replace year=q2126 if year[_n-1]==q2125 & q2126!=. & q2125!=. & q2126!=9998 & q2125!=9998

*Finish for completers
replace year=q2128 if q2128!=. & q2128!=9998 & q2128!=9999 & grade==yrschl
replace year=q2129+brthyr if q2128==9998 & q2129!=98 & q2129!=. & grade==yrschl

la def Lyear 2000 "2000" 2001 "2001" 2002 "2002" 2003 "2003" ///
2004 "2004" 2005 "2005" 2006 "2006" 2007 "2007" 2008 "2008" ///
2009 "2009" 2010 "2010" 2011 "2011" 2012 "2012" 2013 "2013" ///
2014 "2014" 2015 "2015" 2016 "2016"

la val year Lyear

tabu year, miss
tabu year if age>=6, miss

sort indid grade

duplicates report indid grade
*No duplicates on grade
duplicates report indid year
*Some on year, likely mild measurement issues

*browse indid grade year yrschl dropout dropped brthyr dec_age yrstart_basic yrcomplete_basic yrcomplete_secondary yrcomplete_post q2125 q2126 q3001 q3006_a q3006_b if year>2017 & age>=6

*Country TVC
gen in_jordan=1 if year_arrived<=year & group==2

replace in_jordan=0 if in_jordan==. & group==2
*Had already replaced missings with 2013
 
label var in_jordan "in Jordan"
label def Lin_Jordan 0 "In Syria" 1 "In Jordan" , modify

lab val in_jordan Lin_Jordan 

tabu in_jordan group, miss

save "Data/JLMPS annualized- educ.dta", replace
